@@ -132,7 +132,7 @@ static int gnutls_client_cert_cb(gnutls_session session,
 		st->deinit_all = 0;
 		return 0;
 	}
-	return -1;
+	return 0;
 }
 #endif
 
