@@ -253,6 +253,8 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	GtkUIManager *gui_manager = gtkut_ui_manager();
 	GtkActionGroup *actions;
 	NoticeView *siginfoview;
+	GtkRequisition r;
+
 	gchar *titles[N_MIMEVIEW_COLS];
 	gint i;
 	CLAWS_TIP_DECL();
@@ -331,6 +333,7 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	mimeview->ctree_mode = FALSE;
 	arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_NONE);
 	gtk_widget_show(arrow);
+	gtk_widget_size_request(arrow, &r);
 	gtk_container_add(GTK_CONTAINER(mime_toggle), arrow);
 	g_signal_connect(G_OBJECT(mime_toggle), "button_release_event", 
 			 G_CALLBACK(mime_toggle_button_cb), mimeview);
@@ -390,7 +393,7 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	gtk_widget_show(hbox);
 	gtk_widget_hide(ctree_mainbox);
 #ifdef GENERIC_UMPC
-	gtk_widget_set_size_request(mime_toggle, -1, arrow->requisition.height + 8);
+	gtk_widget_set_size_request(mime_toggle, -1, r.height + 8);
 #endif
 	mimeview->hbox          = hbox;
 	mimeview->paned         = paned;
@@ -2164,6 +2167,7 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 	MimeInfo *partinfo;
 	MimeInfo *siginfo = NULL;
 	MimeInfo *encrypted = NULL;
+	GtkRequisition r;
 #if !(GTK_CHECK_VERSION(2,12,0))
 	GtkTooltips *tips = mimeview->tooltips;
 #endif
@@ -2324,8 +2328,8 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 			 G_CALLBACK(mimeview_drag_data_get), mimeview);
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
 #ifdef GENERIC_UMPC
-	gtk_widget_set_size_request(vbox, -1, pixmap->requisition.height + 8);
-	gtk_widget_set_size_request(button, -1, pixmap->requisition.height + 4);
+	gtk_widget_size_request(pixmap, &r);
+	gtk_widget_set_size_request(button, -1, r.height + 4);
 #endif
 
 }
@@ -2359,7 +2363,7 @@ static void icon_scroll_size_allocate_cb(GtkWidget *widget,
 	GtkAllocation *vbox_size;
 	GtkAllocation *layout_size;
 	GtkAdjustment *adj;
-	
+
 	adj = gtk_layout_get_vadjustment(GTK_LAYOUT(mimeview->icon_scroll));
 
 	mainbox_size = &mimeview->icon_mainbox->allocation;
