@@ -239,28 +239,26 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"linewrap_auto", "TRUE", &prefs_common.autowrap, P_BOOL,
 	 NULL, NULL, NULL},
+	{"auto_indent", "TRUE", &prefs_common.auto_indent, P_BOOL,
+	 NULL, NULL, NULL},
         {"autosave", "TRUE", &prefs_common.autosave,
 	 P_BOOL, NULL, NULL, NULL},
         {"autosave_length", "50", &prefs_common.autosave_length, P_INT,
 	 NULL, NULL, NULL},
-#if USE_ASPELL
+#if USE_ENCHANT
 	{"enable_aspell", "TRUE", &prefs_common.enable_aspell, P_BOOL,
 	 NULL, NULL, NULL},
-	{"aspell_path", ASPELL_PATH, &prefs_common.aspell_path, P_STRING,
-	 NULL, NULL, NULL},
 	{"dictionary",  "", &prefs_common.dictionary, P_STRING,
 	 NULL, NULL, NULL},
 	{"alt_dictionary",  "", &prefs_common.alt_dictionary, P_STRING,
 	 NULL, NULL, NULL},
-	{"aspell_sugmode", "1", &prefs_common.aspell_sugmode, P_INT,
-	 NULL, NULL, NULL},
 	{"use_alternate_dict", "FALSE", &prefs_common.use_alternate, P_BOOL,
 	 NULL, NULL, NULL},
 	{"check_while_typing", "TRUE", &prefs_common.check_while_typing, P_BOOL,
 	 NULL, NULL, NULL},
 	{"recheck_when_changing_dict", "TRUE", &prefs_common.recheck_when_changing_dict,
 	 P_BOOL, NULL, NULL, NULL},
-	{"misspelled_color", "16711680", &prefs_common.misspelled_col, P_COLOR,
+	{"misspelled_color", "#ff0000", &prefs_common.misspelled_col, P_COLOR,
 	 NULL, NULL, NULL},
 	{"use_both_dicts", "FALSE", &prefs_common.use_both_dicts, P_BOOL,
 	 NULL, NULL, NULL},
@@ -295,7 +293,7 @@ static PrefParam param[] = {
 	/* Quote */
 	{"reply_quote_mark", "> ", &prefs_common.quotemark, P_STRING,
 	 NULL, NULL, NULL},
-	{"reply_quote_format", N_("On %d\\n%f wrote:\\n\\n%q"),
+	{"reply_quote_format", N_("On %d\\n%f wrote:\\n\\n%q\\n%X"),
 	 &prefs_common.quotefmt, P_STRING, NULL, NULL, NULL},
 
 	{"forward_quote_mark", "> ", &prefs_common.fw_quotemark, P_STRING,
@@ -679,27 +677,27 @@ static PrefParam param[] = {
 	{"enable_color", "TRUE", &prefs_common.enable_color, P_BOOL,
 	 NULL, NULL, NULL},
 
-	{"quote_level1_color", "179", &prefs_common.quote_level1_col, P_COLOR,
+	{"quote_level1_color", "#0000b3", &prefs_common.quote_level1_col, P_COLOR,
 	 NULL, NULL, NULL},
-	{"quote_level2_color", "179", &prefs_common.quote_level2_col, P_COLOR,
+	{"quote_level2_color", "#0000b3", &prefs_common.quote_level2_col, P_COLOR,
 	 NULL, NULL, NULL},
-	{"quote_level3_color", "179", &prefs_common.quote_level3_col, P_COLOR,
+	{"quote_level3_color", "#0000b3", &prefs_common.quote_level3_col, P_COLOR,
 	 NULL, NULL, NULL},
 	{"enable_bgcolor", "FALSE", &prefs_common.enable_bgcolor, P_BOOL,
 	 NULL, NULL, NULL},
-	{"quote_level1_bgcolor", "13421772", &prefs_common.quote_level1_bgcol, P_COLOR,
+	{"quote_level1_bgcolor", "#cccccc", &prefs_common.quote_level1_bgcol, P_COLOR,
 	 NULL, NULL, NULL},
-	{"quote_level2_bgcolor", "13948116", &prefs_common.quote_level2_bgcol, P_COLOR,
+	{"quote_level2_bgcolor", "#d4d4d4", &prefs_common.quote_level2_bgcol, P_COLOR,
 	 NULL, NULL, NULL},
-	{"quote_level3_bgcolor", "14540253", &prefs_common.quote_level3_bgcol, P_COLOR,
+	{"quote_level3_bgcolor", "#dddddd", &prefs_common.quote_level3_bgcol, P_COLOR,
 	 NULL, NULL, NULL},
-	{"uri_color", "32512", &prefs_common.uri_col, P_COLOR,
+	{"uri_color", "#007f00", &prefs_common.uri_col, P_COLOR,
 	 NULL, NULL, NULL},
-	{"emphasis_color", "207", &prefs_common.emphasis_col, P_COLOR,
+	{"emphasis_color", "#0000cf", &prefs_common.emphasis_col, P_COLOR,
 	 NULL, NULL, NULL},
-	{"target_folder_color", "14294218", &prefs_common.tgt_folder_col, P_COLOR,
+	{"target_folder_color", "#da1cca", &prefs_common.tgt_folder_col, P_COLOR,
 	 NULL, NULL, NULL},
-	{"signature_color", "7960953", &prefs_common.signature_col, P_COLOR,
+	{"signature_color", "#797979", &prefs_common.signature_col, P_COLOR,
 	 NULL, NULL, NULL},
 	{"recycle_quote_colors", "FALSE", &prefs_common.recycle_quote_colors,
 	 P_BOOL, NULL, NULL, NULL},
@@ -757,9 +755,9 @@ static PrefParam param[] = {
 #endif
 	/* {"emulate_emacs", "FALSE", &prefs_common.emulate_emacs, P_BOOL,
 	 NULL, NULL, NULL}, */
-	{"always_show_message_when_selected", "FALSE",
+	{"always_show_message_when_selected", "0",
 	 &prefs_common.always_show_msg,
-	 P_BOOL, NULL, NULL, NULL},
+	 P_ENUM, NULL, NULL, NULL},
 	{"select_on_entry", "3", &prefs_common.select_on_entry,
 	 P_ENUM, NULL, NULL, NULL},
 	{"show_tooltips", "TRUE", &prefs_common.show_tooltips,
@@ -823,6 +821,8 @@ static PrefParam param[] = {
 	 &prefs_common.cmds_use_system_default, P_BOOL, NULL, NULL, NULL},
 	{"add_address_by_click", "FALSE", &prefs_common.add_address_by_click,
 	 P_BOOL, NULL, NULL, NULL},
+	{"session_passwords", "FALSE", &prefs_common.session_passwords,
+	 P_BOOL, NULL, NULL, NULL},
 	{"confirm_on_exit", "FALSE", &prefs_common.confirm_on_exit, P_BOOL,
 	 NULL, NULL, NULL},
 	{"clean_trash_on_exit", "FALSE", &prefs_common.clean_on_exit, P_BOOL,
@@ -917,7 +917,7 @@ static PrefParam param[] = {
 	{"gtk_can_change_accels", "TRUE", &prefs_common.gtk_can_change_accels, P_BOOL,
 	 NULL, NULL, NULL},
 
-	{"color_new", "179", &prefs_common.color_new, P_COLOR,
+	{"color_new", "#0000b3", &prefs_common.color_new, P_COLOR,
 	 NULL, NULL, NULL},
 
 	/* Some windows' sizes */
@@ -1552,3 +1552,8 @@ gboolean prefs_common_get_use_shred(void)
 {
 	return prefs_common.use_shred;
 }
+
+PrefsCommon *prefs_common_get_prefs(void)
+{
+	return &prefs_common;
+}
