@@ -497,7 +497,6 @@ static void prefs_other_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkWidget *frame_keys;
 	GtkWidget *vbox_keys;
 	GtkWidget *checkbtn_gtk_can_change_accels;
-	GtkTooltips *tooltips;
 	GtkWidget *button_keybind;
 
 	GtkWidget *label_iotimeout;
@@ -509,7 +508,10 @@ static void prefs_other_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkWidget *checkbtn_askonfilter;
 	GtkWidget *checkbtn_use_shred;
 	GtkWidget *checkbtn_real_time_sync;
+
 	gchar *shred_binary = NULL;
+	CLAWS_TIP_DECL();
+
 	vbox1 = gtk_vbox_new (FALSE, VSPACING);
 	gtk_widget_show (vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), VBOX_BORDER);
@@ -540,15 +542,13 @@ static void prefs_other_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	PACK_CHECK_BUTTON(vbox_keys, checkbtn_gtk_can_change_accels,
 			_("Enable customisable keyboard shortcuts"));
-	tooltips = gtk_tooltips_new();
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips),
-			checkbtn_gtk_can_change_accels,
+
+	CLAWS_SET_TIP(checkbtn_gtk_can_change_accels,
 			_("If checked, you can change the keyboard shortcuts of "
 				"most of the menu items by focusing on the menu "
 				"item and pressing a key combination.\n"
 				"Uncheck this option if you want to lock all "
-				"existing keyboard shortcuts."),
-			NULL);
+				"existing keyboard shortcuts."));
 
 	button_keybind = gtk_button_new_with_label(
 				_(" Choose preset keyboard shortcuts... "));
@@ -601,12 +601,10 @@ static void prefs_other_create_widget(PrefsPage *_page, GtkWindow *window,
 				     "(the 'shred' program is not available)"));
 		gtk_widget_set_sensitive(checkbtn_use_shred, FALSE);
 	}
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips),
-			checkbtn_use_shred,
+	CLAWS_SET_TIP(checkbtn_use_shred,
 			_("Use the 'shred' program to overwrite files with random data before "
 			  "deleting them. This slows down deletion. Be sure to "
-			  "read shred's man page for caveats."),
-			NULL);
+			  "read shred's man page for caveats."));
 	PACK_CHECK_BUTTON (vbox2, checkbtn_real_time_sync,
 			   _("Synchronise offline folders as soon as possible"));
 
@@ -651,6 +649,7 @@ static void prefs_other_save(PrefsPage *_page)
 {
 	OtherPage *page = (OtherPage *) _page;
 	gboolean gtk_can_change_accels;
+	GList * list = NULL;
 
 	prefs_common.add_address_by_click = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_addaddrbyclick));
